package App::CharmKit;
$App::CharmKit::VERSION = '2.05';
# ABSTRACT: ezpz Juju charm authoring

use strict;
use warnings;
use App::Cmd::Setup -app;

1;

__END__

=pod

=head1 NAME

App::CharmKit - ezpz Juju charm authoring

=head1 AUTHOR

Adam Stokes <adamjs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Adam Stokes.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
